<?php namespace EscapeWork\Manager;

use \Eloquent;
use Illuminate\Auth\UserInterface;
use Illuminate\Auth\Reminders\RemindableInterface;

class User extends Eloquent implements UserInterface, RemindableInterface
{

    /**
     * Tabela
     */
    protected $table = 'users';

    /**
     * The attributes excluded from the model's JSON form.
     *
     * @var array
     */
    protected $hidden = array('password');

    /**
     * Regras para validação
     */
    public static $validationRules = array(
        'name'  => array('required'), 
        'email' => array('required', 'email', 'unique' => 'unique:users'), 
    );

    /**
     * Mensagens para validação
     */
    public static $validationMessages = array(
        'name.required'  => 'O nome do usuário é obrigatório', 
        'email.required' => 'O e-mail do usuário é obrigatório', 
        'email.email'    => 'O e-mail do usuário é precisa ser válido', 
        'email.unique'   => 'O e-mail digitado já está cadastrado em outro usuário. Selecione outro.', 
    );

    /**
     * Get the unique identifier for the user.
     *
     * @return mixed
     */
    public function getAuthIdentifier()
    {
        return $this->getKey();
    }

    /**
     * Get the password for the user.
     *
     * @return string
     */
    public function getAuthPassword()
    {
        return $this->password;
    }

    /**
     * Get the e-mail address where password reminders are sent.
     *
     * @return string
     */
    public function getReminderEmail()
    {
        return $this->email;
    }
}